Registration

Struct Registration 

pub struct Registration<T: 'static> { /* private fields */ }
The registration of an auxiliary device.

This type represents the registration of a [struct auxiliary_device]. When its parent device is unbound, the corresponding auxiliary device will be unregistered from the system.

The type parameter T is the type of the registration data owned by the registering (parent) driver. It can be accessed by the auxiliary driver through Device::registration_data().

Invariants

self.adev always holds a valid pointer to an initialized and registered [struct auxiliary_device] whose registration_data_rust field points to a valid Pin<KBox<RegistrationData<T>>>.

Implementations

Source

impl<T: Send + Sync + 'static> Registration<T>

pub fn new<E>( parent: &Device<Bound>, name: &CStr, id: u32, modname: &CStr, data: impl PinInit<T, E>, ) -> Result<Devres<Self>>
where Error: From<E>,

Create and register a new auxiliary device with the given registration data.

The data is owned by the registration and can be accessed through the auxiliary device via Device::registration_data().